@@ -1,26 +1,29 @@
-from __future__ import division
 import pytest
 
 import numpy as np
+from functools import partial
 import itertools
 
+from sklearn.base import clone
+
 from sklearn.exceptions import ConvergenceWarning
 
 from sklearn.utils import check_array
 
-from sklearn.utils.testing import assert_array_almost_equal
-from sklearn.utils.testing import assert_array_equal
-from sklearn.utils.testing import assert_equal
-from sklearn.utils.testing import assert_less
-from sklearn.utils.testing import assert_raises
-from sklearn.utils.testing import ignore_warnings
-from sklearn.utils.testing import TempMemmap
+from sklearn.utils._testing import assert_array_almost_equal
+from sklearn.utils._testing import assert_array_equal
+from sklearn.utils._testing import ignore_warnings
+from sklearn.utils._testing import TempMemmap
 
 from sklearn.decomposition import DictionaryLearning
 from sklearn.decomposition import MiniBatchDictionaryLearning
 from sklearn.decomposition import SparseCoder
+from sklearn.decomposition import dict_learning
 from sklearn.decomposition import dict_learning_online
 from sklearn.decomposition import sparse_encode
+from sklearn.utils.estimator_checks import check_transformer_data_not_an_array
+from sklearn.utils.estimator_checks import check_transformer_general
+from sklearn.utils.estimator_checks import check_transformers_unfitted
 
 
 rng_global = np.random.RandomState(0)
@@ -37,18 +40,18 @@ def test_sparse_encode_shapes_omp():
         for algorithm, n_jobs in itertools.product(algorithms, [1, 3]):
             code = sparse_encode(X_, dictionary, algorithm=algorithm,
                                  n_jobs=n_jobs)
-            assert_equal(code.shape, (n_samples, n_components))
+            assert code.shape == (n_samples, n_components)
 
 
 def test_dict_learning_shapes():
     n_components = 5
     dico = DictionaryLearning(n_components, random_state=0).fit(X)
-    assert_equal(dico.components_.shape, (n_components, n_features))
+    assert dico.components_.shape == (n_components, n_features)
 
     n_components = 1
     dico = DictionaryLearning(n_components, random_state=0).fit(X)
-    assert_equal(dico.components_.shape, (n_components, n_features))
-    assert_equal(dico.transform(X).shape, (X.shape[0], n_components))
+    assert dico.components_.shape == (n_components, n_features)
+    assert dico.transform(X).shape == (X.shape[0], n_components)
 
 
 def test_dict_learning_overcomplete():
@@ -57,29 +60,78 @@ def test_dict_learning_overcomplete():
     assert dico.components_.shape == (n_components, n_features)
 
 
-# positive lars deprecated 0.22
-@pytest.mark.filterwarnings('ignore::DeprecationWarning')
+def test_max_iter():
+    def ricker_function(resolution, center, width):
+        """Discrete sub-sampled Ricker (Mexican hat) wavelet"""
+        x = np.linspace(0, resolution - 1, resolution)
+        x = ((2 / (np.sqrt(3 * width) * np.pi ** .25))
+             * (1 - (x - center) ** 2 / width ** 2)
+             * np.exp(-(x - center) ** 2 / (2 * width ** 2)))
+        return x
+
+    def ricker_matrix(width, resolution, n_components):
+        """Dictionary of Ricker (Mexican hat) wavelets"""
+        centers = np.linspace(0, resolution - 1, n_components)
+        D = np.empty((n_components, resolution))
+        for i, center in enumerate(centers):
+            D[i] = ricker_function(resolution, center, width)
+        D /= np.sqrt(np.sum(D ** 2, axis=1))[:, np.newaxis]
+        return D
+
+    transform_algorithm = 'lasso_cd'
+    resolution = 1024
+    subsampling = 3  # subsampling factor
+    n_components = resolution // subsampling
+
+    # Compute a wavelet dictionary
+    D_multi = np.r_[tuple(ricker_matrix(width=w, resolution=resolution,
+                          n_components=n_components // 5)
+                          for w in (10, 50, 100, 500, 1000))]
+
+    X = np.linspace(0, resolution - 1, resolution)
+    first_quarter = X < resolution / 4
+    X[first_quarter] = 3.
+    X[np.logical_not(first_quarter)] = -1.
+    X = X.reshape(1, -1)
+
+    # check that the underlying model fails to converge
+    with pytest.warns(ConvergenceWarning):
+        model = SparseCoder(D_multi, transform_algorithm=transform_algorithm,
+                            transform_max_iter=1)
+        model.fit_transform(X)
+
+    # check that the underlying model converges w/o warnings
+    with pytest.warns(None) as record:
+        model = SparseCoder(D_multi, transform_algorithm=transform_algorithm,
+                            transform_max_iter=2000)
+        model.fit_transform(X)
+    assert not record.list
+
+
+def test_dict_learning_lars_positive_parameter():
+    n_components = 5
+    alpha = 1
+    err_msg = "Positive constraint not supported for 'lars' coding method."
+    with pytest.raises(ValueError, match=err_msg):
+        dict_learning(X, n_components, alpha=alpha, positive_code=True)
+
+
 @pytest.mark.parametrize("transform_algorithm", [
     "lasso_lars",
     "lasso_cd",
-    "lars",
     "threshold",
 ])
-@pytest.mark.parametrize("positive_code", [
-    False,
-    True,
-])
-@pytest.mark.parametrize("positive_dict", [
-    False,
-    True,
-])
+@pytest.mark.parametrize("positive_code", [False, True])
+@pytest.mark.parametrize("positive_dict", [False, True])
 def test_dict_learning_positivity(transform_algorithm,
                                   positive_code,
                                   positive_dict):
     n_components = 5
     dico = DictionaryLearning(
         n_components, transform_algorithm=transform_algorithm, random_state=0,
-        positive_code=positive_code, positive_dict=positive_dict).fit(X)
+        positive_code=positive_code, positive_dict=positive_dict,
+        fit_algorithm="cd").fit(X)
+
     code = dico.transform(X)
     if positive_dict:
         assert (dico.components_ >= 0).all()
@@ -91,6 +143,31 @@ def test_dict_learning_positivity(transform_algorithm,
         assert (code < 0).any()
 
 
+@pytest.mark.parametrize("positive_dict", [False, True])
+def test_dict_learning_lars_dict_positivity(positive_dict):
+    n_components = 5
+    dico = DictionaryLearning(
+        n_components, transform_algorithm="lars", random_state=0,
+        positive_dict=positive_dict, fit_algorithm="cd").fit(X)
+
+    if positive_dict:
+        assert (dico.components_ >= 0).all()
+    else:
+        assert (dico.components_ < 0).any()
+
+
+def test_dict_learning_lars_code_positivity():
+    n_components = 5
+    dico = DictionaryLearning(
+        n_components, transform_algorithm="lars", random_state=0,
+        positive_code=True, fit_algorithm="cd").fit(X)
+
+    err_msg = "Positive constraint not supported for '{}' coding method."
+    err_msg = err_msg.format("lars")
+    with pytest.raises(ValueError, match=err_msg):
+        dico.transform(X)
+
+
 def test_dict_learning_reconstruction():
     n_components = 12
     dico = DictionaryLearning(n_components, transform_algorithm='omp',
@@ -107,10 +184,10 @@ def test_dict_learning_reconstruction():
 
 
 def test_dict_learning_reconstruction_parallel():
-    # regression test that parallel reconstruction works with n_jobs=-1
+    # regression test that parallel reconstruction works with n_jobs>1
     n_components = 12
     dico = DictionaryLearning(n_components, transform_algorithm='omp',
-                              transform_alpha=0.001, random_state=0, n_jobs=-1)
+                              transform_alpha=0.001, random_state=0, n_jobs=4)
     code = dico.fit(X).transform(X)
     assert_array_almost_equal(np.dot(code, dico.components_), X)
 
@@ -124,7 +201,7 @@ def test_dict_learning_lassocd_readonly_data():
     with TempMemmap(X) as X_read_only:
         dico = DictionaryLearning(n_components, transform_algorithm='lasso_cd',
                                   transform_alpha=0.001, random_state=0,
-                                  n_jobs=-1)
+                                  n_jobs=4)
         with ignore_warnings(category=ConvergenceWarning):
             code = dico.fit(X_read_only).transform(X_read_only)
         assert_array_almost_equal(np.dot(code, dico.components_), X_read_only,
@@ -140,13 +217,14 @@ def test_dict_learning_nonzero_coefs():
 
     dico.set_params(transform_algorithm='omp')
     code = dico.transform(X[np.newaxis, 1])
-    assert_equal(len(np.flatnonzero(code)), 3)
+    assert len(np.flatnonzero(code)) == 3
 
 
 def test_dict_learning_unknown_fit_algorithm():
     n_components = 5
     dico = DictionaryLearning(n_components, fit_algorithm='<unknown>')
-    assert_raises(ValueError, dico.fit, X)
+    with pytest.raises(ValueError):
+        dico.fit(X)
 
 
 def test_dict_learning_split():
@@ -166,36 +244,34 @@ def test_dict_learning_online_shapes():
     n_components = 8
     code, dictionary = dict_learning_online(X, n_components=n_components,
                                             alpha=1, random_state=rng)
-    assert_equal(code.shape, (n_samples, n_components))
-    assert_equal(dictionary.shape, (n_components, n_features))
-    assert_equal(np.dot(code, dictionary).shape, X.shape)
+    assert code.shape == (n_samples, n_components)
+    assert dictionary.shape == (n_components, n_features)
+    assert np.dot(code, dictionary).shape == X.shape
+
+
+def test_dict_learning_online_lars_positive_parameter():
+    alpha = 1
+    err_msg = "Positive constraint not supported for 'lars' coding method."
+    with pytest.raises(ValueError, match=err_msg):
+        dict_learning_online(X, alpha=alpha, positive_code=True)
 
 
-# positive lars deprecated 0.22
-@pytest.mark.filterwarnings('ignore::DeprecationWarning')
 @pytest.mark.parametrize("transform_algorithm", [
     "lasso_lars",
     "lasso_cd",
-    "lars",
     "threshold",
 ])
-@pytest.mark.parametrize("positive_code", [
-    False,
-    True,
-])
-@pytest.mark.parametrize("positive_dict", [
-    False,
-    True,
-])
-def test_dict_learning_online_positivity(transform_algorithm,
-                                         positive_code,
-                                         positive_dict):
-    rng = np.random.RandomState(0)
+@pytest.mark.parametrize("positive_code", [False, True])
+@pytest.mark.parametrize("positive_dict", [False, True])
+def test_minibatch_dictionary_learning_positivity(transform_algorithm,
+                                                  positive_code,
+                                                  positive_dict):
     n_components = 8
-
     dico = MiniBatchDictionaryLearning(
         n_components, transform_algorithm=transform_algorithm, random_state=0,
-        positive_code=positive_code, positive_dict=positive_dict).fit(X)
+        positive_code=positive_code, positive_dict=positive_dict,
+        fit_algorithm='cd').fit(X)
+
     code = dico.transform(X)
     if positive_dict:
         assert (dico.components_ >= 0).all()
@@ -206,7 +282,30 @@ def test_dict_learning_online_positivity(transform_algorithm,
     else:
         assert (code < 0).any()
 
+
+@pytest.mark.parametrize("positive_dict", [False, True])
+def test_minibatch_dictionary_learning_lars(positive_dict):
+    n_components = 8
+
+    dico = MiniBatchDictionaryLearning(
+        n_components, transform_algorithm="lars", random_state=0,
+        positive_dict=positive_dict, fit_algorithm='cd').fit(X)
+
+    if positive_dict:
+        assert (dico.components_ >= 0).all()
+    else:
+        assert (dico.components_ < 0).any()
+
+
+@pytest.mark.parametrize("positive_code", [False, True])
+@pytest.mark.parametrize("positive_dict", [False, True])
+def test_dict_learning_online_positivity(positive_code,
+                                         positive_dict):
+    rng = np.random.RandomState(0)
+    n_components = 8
+
     code, dictionary = dict_learning_online(X, n_components=n_components,
+                                            method="cd",
                                             alpha=1, random_state=rng,
                                             positive_dict=positive_dict,
                                             positive_code=positive_code)
@@ -223,7 +322,7 @@ def test_dict_learning_online_positivity(transform_algorithm,
 def test_dict_learning_online_verbosity():
     n_components = 5
     # test verbosity
-    from sklearn.externals.six.moves import cStringIO as StringIO
+    from io import StringIO
     import sys
 
     old_stdout = sys.stdout
@@ -298,6 +397,23 @@ def test_dict_learning_online_partial_fit():
                               decimal=2)
 
 
+def test_dict_learning_iter_offset():
+    n_components = 12
+    rng = np.random.RandomState(0)
+    V = rng.randn(n_components, n_features)
+    dict1 = MiniBatchDictionaryLearning(n_components, n_iter=10,
+                                        dict_init=V, random_state=0,
+                                        shuffle=False)
+    dict2 = MiniBatchDictionaryLearning(n_components, n_iter=10,
+                                        dict_init=V, random_state=0,
+                                        shuffle=False)
+    dict1.fit(X)
+    for sample in X:
+        dict2.partial_fit(sample[np.newaxis, :])
+
+    assert dict1.iter_offset_ == dict2.iter_offset_
+
+
 def test_sparse_encode_shapes():
     n_components = 12
     rng = np.random.RandomState(0)
@@ -305,32 +421,37 @@ def test_sparse_encode_shapes():
     V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
     for algo in ('lasso_lars', 'lasso_cd', 'lars', 'omp', 'threshold'):
         code = sparse_encode(X, V, algorithm=algo)
-        assert_equal(code.shape, (n_samples, n_components))
+        assert code.shape == (n_samples, n_components)
 
 
-# positive lars deprecated 0.22
-@pytest.mark.filterwarnings('ignore::DeprecationWarning')
-@pytest.mark.parametrize("positive", [
-    False,
-    True,
+@pytest.mark.parametrize("algo", [
+    'lasso_lars',
+    'lasso_cd',
+    'threshold'
 ])
-def test_sparse_encode_positivity(positive):
+@pytest.mark.parametrize("positive", [False, True])
+def test_sparse_encode_positivity(algo, positive):
     n_components = 12
     rng = np.random.RandomState(0)
     V = rng.randn(n_components, n_features)  # random init
     V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
-    for algo in ('lasso_lars', 'lasso_cd', 'lars', 'threshold'):
-        code = sparse_encode(X, V, algorithm=algo, positive=positive)
-        if positive:
-            assert (code >= 0).all()
-        else:
-            assert (code < 0).any()
+    code = sparse_encode(X, V, algorithm=algo, positive=positive)
+    if positive:
+        assert (code >= 0).all()
+    else:
+        assert (code < 0).any()
 
-    try:
-        sparse_encode(X, V, algorithm='omp', positive=positive)
-    except ValueError:
-        if not positive:
-            raise
+
+@pytest.mark.parametrize("algo", ['lars', 'omp'])
+def test_sparse_encode_unavailable_positivity(algo):
+    n_components = 12
+    rng = np.random.RandomState(0)
+    V = rng.randn(n_components, n_features)  # random init
+    V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
+    err_msg = "Positive constraint not supported for '{}' coding method."
+    err_msg = err_msg.format(algo)
+    with pytest.raises(ValueError, match=err_msg):
+        sparse_encode(X, V, algorithm=algo, positive=True)
 
 
 def test_sparse_encode_input():
@@ -352,7 +473,7 @@ def test_sparse_encode_error():
     V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
     code = sparse_encode(X, V, alpha=0.001)
     assert not np.all(code == 0)
-    assert_less(np.sqrt(np.sum((np.dot(code, V) - X) ** 2)), 0.1)
+    assert np.sqrt(np.sum((np.dot(code, V) - X) ** 2)) < 0.1
 
 
 def test_sparse_encode_error_default_sparsity():
@@ -361,14 +482,15 @@ def test_sparse_encode_error_default_sparsity():
     D = rng.randn(2, 64)
     code = ignore_warnings(sparse_encode)(X, D, algorithm='omp',
                                           n_nonzero_coefs=None)
-    assert_equal(code.shape, (100, 2))
+    assert code.shape == (100, 2)
 
 
 def test_unknown_method():
     n_components = 12
     rng = np.random.RandomState(0)
     V = rng.randn(n_components, n_features)  # random init
-    assert_raises(ValueError, sparse_encode, X, V, algorithm="<unknown>")
+    with pytest.raises(ValueError):
+        sparse_encode(X, V, algorithm="<unknown>")
 
 
 def test_sparse_coder_estimator():
@@ -376,10 +498,28 @@ def test_sparse_coder_estimator():
     rng = np.random.RandomState(0)
     V = rng.randn(n_components, n_features)  # random init
     V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
-    code = SparseCoder(dictionary=V, transform_algorithm='lasso_lars',
-                       transform_alpha=0.001).transform(X)
-    assert not np.all(code == 0)
-    assert_less(np.sqrt(np.sum((np.dot(code, V) - X) ** 2)), 0.1)
+    coder = SparseCoder(dictionary=V, transform_algorithm='lasso_lars',
+                        transform_alpha=0.001).transform(X)
+    assert not np.all(coder == 0)
+    assert np.sqrt(np.sum((np.dot(coder, V) - X) ** 2)) < 0.1
+
+
+def test_sparse_coder_estimator_clone():
+    n_components = 12
+    rng = np.random.RandomState(0)
+    V = rng.randn(n_components, n_features)  # random init
+    V /= np.sum(V ** 2, axis=1)[:, np.newaxis]
+    coder = SparseCoder(dictionary=V, transform_algorithm='lasso_lars',
+                        transform_alpha=0.001)
+    cloned = clone(coder)
+    assert id(cloned) != id(coder)
+    np.testing.assert_allclose(cloned.dictionary, coder.dictionary)
+    assert id(cloned.dictionary) != id(coder.dictionary)
+    assert cloned.n_components_ == coder.n_components_
+    assert cloned.n_features_in_ == coder.n_features_in_
+    data = np.random.rand(n_samples, n_features).astype(np.float32)
+    np.testing.assert_allclose(cloned.transform(data),
+                               coder.transform(data))
 
 
 def test_sparse_coder_parallel_mmap():
@@ -399,3 +539,37 @@ def test_sparse_coder_parallel_mmap():
 
     sc = SparseCoder(init_dict, transform_algorithm='omp', n_jobs=2)
     sc.fit_transform(data)
+
+
+def test_sparse_coder_common_transformer():
+    rng = np.random.RandomState(777)
+    n_components, n_features = 40, 3
+    init_dict = rng.rand(n_components, n_features)
+
+    sc = SparseCoder(init_dict)
+
+    check_transformer_data_not_an_array(sc.__class__.__name__, sc)
+    check_transformer_general(sc.__class__.__name__, sc)
+    check_transformer_general_memmap = partial(
+        check_transformer_general, readonly_memmap=True
+    )
+    check_transformer_general_memmap(sc.__class__.__name__, sc)
+    check_transformers_unfitted(sc.__class__.__name__, sc)
+
+
+# TODO: remove in 1.1
+def test_sparse_coder_deprecation():
+    # check that we raise a deprecation warning when accessing `components_`
+    rng = np.random.RandomState(777)
+    n_components, n_features = 40, 64
+    init_dict = rng.rand(n_components, n_features)
+    sc = SparseCoder(init_dict)
+
+    with pytest.warns(FutureWarning, match="'components_' is deprecated"):
+        sc.components_
+
+
+def test_sparse_coder_n_features_in():
+    d = np.array([[1, 2, 3], [1, 2, 3]])
+    sc = SparseCoder(d)
+    assert sc.n_features_in_ == d.shape[1]
