@@ -51,7 +51,7 @@ def f_oneway(*args):
 
     Parameters
     ----------
-    *args : array_like, sparse matrices
+    *args : array-like, sparse matrices
         sample1, sample2... The sample measurements should be given as
         arguments.
 
@@ -141,10 +141,10 @@ def f_classif(X, y):
     pval : array, shape = [n_features,]
         The set of p-values.
 
-    See also
+    See Also
     --------
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
     """
     X, y = check_X_y(X, y, accept_sparse=['csr', 'csc', 'coo'])
     args = [X[safe_mask(X, y == k)] for k in np.unique(y)]
@@ -204,10 +204,10 @@ def chi2(X, y):
     -----
     Complexity of this algorithm is O(n_classes * n_features).
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
     """
 
     # XXX: we might want to do some of the following in logspace instead for
@@ -229,7 +229,8 @@ def chi2(X, y):
     return _chisquare(observed, expected)
 
 
-def f_regression(X, y, center=True):
+@_deprecate_positional_args
+def f_regression(X, y, *, center=True):
     """Univariate linear regression tests.
 
     Linear model for testing the individual effect of each of many regressors.
@@ -253,7 +254,7 @@ def f_regression(X, y, center=True):
     y : array of shape(n_samples).
         The data matrix
 
-    center : True, bool,
+    center : bool, default=True
         If true, X and y will be centered.
 
     Returns
@@ -264,17 +265,16 @@ def f_regression(X, y, center=True):
     pval : array, shape=(n_features,)
         p-values of F-scores.
 
-
-    See also
+    See Also
     --------
-    mutual_info_regression: Mutual information for a continuous target.
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    SelectFwe: Select features based on family-wise error rate.
-    SelectPercentile: Select features based on percentile of the highest
+    mutual_info_regression : Mutual information for a continuous target.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    SelectFwe : Select features based on family-wise error rate.
+    SelectPercentile : Select features based on percentile of the highest
         scores.
     """
     X, y = check_X_y(X, y, accept_sparse=['csr', 'csc', 'coo'],
@@ -378,15 +378,15 @@ class SelectPercentile(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues) or a single array with scores.
-        Default is f_classif (see below "See also"). The default function only
+        Default is f_classif (see below "See Also"). The default function only
         works with classification tasks.
 
         .. versionadded:: 0.18
 
-    percentile : int, optional, default=10
+    percentile : int, default=10
         Percent of features to keep.
 
     Attributes
@@ -413,18 +413,19 @@ class SelectPercentile(_BaseFilter):
     Ties between features with equal scores will be broken in an unspecified
     way.
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    mutual_info_classif: Mutual information for a discrete target.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
-    mutual_info_regression: Mutual information for a continuous target.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    SelectFwe: Select features based on family-wise error rate.
-    GenericUnivariateSelect: Univariate feature selector with configurable mode.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    mutual_info_classif : Mutual information for a discrete target.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
+    mutual_info_regression : Mutual information for a continuous target.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    SelectFwe : Select features based on family-wise error rate.
+    GenericUnivariateSelect : Univariate feature selector with configurable
+        mode.
     """
     @_deprecate_positional_args
     def __init__(self, score_func=f_classif, *, percentile=10):
@@ -441,9 +442,9 @@ class SelectPercentile(_BaseFilter):
 
         # Cater for NaNs
         if self.percentile == 100:
-            return np.ones(len(self.scores_), dtype=np.bool)
+            return np.ones(len(self.scores_), dtype=bool)
         elif self.percentile == 0:
-            return np.zeros(len(self.scores_), dtype=np.bool)
+            return np.zeros(len(self.scores_), dtype=bool)
 
         scores = _clean_nans(self.scores_)
         threshold = np.percentile(scores, 100 - self.percentile)
@@ -463,15 +464,15 @@ class SelectKBest(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues) or a single array with scores.
-        Default is f_classif (see below "See also"). The default function only
+        Default is f_classif (see below "See Also"). The default function only
         works with classification tasks.
 
         .. versionadded:: 0.18
 
-    k : int or "all", optional, default=10
+    k : int or "all", default=10
         Number of top features to select.
         The "all" option bypasses selection, for use in a parameter search.
 
@@ -499,18 +500,20 @@ class SelectKBest(_BaseFilter):
     Ties between features with equal scores will be broken in an unspecified
     way.
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    mutual_info_classif: Mutual information for a discrete target.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
-    mutual_info_regression: Mutual information for a continuous target.
-    SelectPercentile: Select features based on percentile of the highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    SelectFwe: Select features based on family-wise error rate.
-    GenericUnivariateSelect: Univariate feature selector with configurable mode.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    mutual_info_classif : Mutual information for a discrete target.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
+    mutual_info_regression : Mutual information for a continuous target.
+    SelectPercentile : Select features based on percentile of the highest
+        scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    SelectFwe : Select features based on family-wise error rate.
+    GenericUnivariateSelect : Univariate feature selector with configurable
+        mode.
     """
     @_deprecate_positional_args
     def __init__(self, score_func=f_classif, *, k=10):
@@ -550,13 +553,13 @@ class SelectFpr(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues).
-        Default is f_classif (see below "See also"). The default function only
+        Default is f_classif (see below "See Also"). The default function only
         works with classification tasks.
 
-    alpha : float, optional
+    alpha : float, default=5e-2
         The highest p-value for features to be kept.
 
     Attributes
@@ -578,18 +581,20 @@ class SelectFpr(_BaseFilter):
     >>> X_new.shape
     (569, 16)
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    mutual_info_classif:
-    f_regression: F-value between label/feature for regression tasks.
-    mutual_info_regression: Mutual information between features and the target.
-    SelectPercentile: Select features based on percentile of the highest scores.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    SelectFwe: Select features based on family-wise error rate.
-    GenericUnivariateSelect: Univariate feature selector with configurable mode.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    mutual_info_classif: Mutual information for a discrete target.
+    f_regression : F-value between label/feature for regression tasks.
+    mutual_info_regression : Mutual information for a continuous target.
+    SelectPercentile : Select features based on percentile of the highest
+        scores.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    SelectFwe : Select features based on family-wise error rate.
+    GenericUnivariateSelect : Univariate feature selector with configurable
+        mode.
     """
     @_deprecate_positional_args
     def __init__(self, score_func=f_classif, *, alpha=5e-2):
@@ -612,13 +617,13 @@ class SelectFdr(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues).
-        Default is f_classif (see below "See also"). The default function only
+        Default is f_classif (see below "See Also"). The default function only
         works with classification tasks.
 
-    alpha : float, optional
+    alpha : float, default=5e-2
         The highest uncorrected p-value for features to keep.
 
     Examples
@@ -644,18 +649,20 @@ class SelectFdr(_BaseFilter):
     ----------
     https://en.wikipedia.org/wiki/False_discovery_rate
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    mutual_info_classif: Mutual information for a discrete target.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
-    mutual_info_regression: Mutual information for a contnuous target.
-    SelectPercentile: Select features based on percentile of the highest scores.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFwe: Select features based on family-wise error rate.
-    GenericUnivariateSelect: Univariate feature selector with configurable mode.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    mutual_info_classif : Mutual information for a discrete target.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
+    mutual_info_regression : Mutual information for a contnuous target.
+    SelectPercentile : Select features based on percentile of the highest
+        scores.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFwe : Select features based on family-wise error rate.
+    GenericUnivariateSelect : Univariate feature selector with configurable
+        mode.
     """
     @_deprecate_positional_args
     def __init__(self, score_func=f_classif, *, alpha=5e-2):
@@ -681,13 +688,13 @@ class SelectFwe(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues).
-        Default is f_classif (see below "See also"). The default function only
+        Default is f_classif (see below "See Also"). The default function only
         works with classification tasks.
 
-    alpha : float, optional
+    alpha : float, default=5e-2
         The highest uncorrected p-value for features to keep.
 
     Examples
@@ -709,16 +716,18 @@ class SelectFwe(_BaseFilter):
     pvalues_ : array-like of shape (n_features,)
         p-values of feature scores.
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
-    SelectPercentile: Select features based on percentile of the highest scores.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    GenericUnivariateSelect: Univariate feature selector with configurable mode.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
+    SelectPercentile : Select features based on percentile of the highest
+        scores.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    GenericUnivariateSelect : Univariate feature selector with configurable
+        mode.
     """
     @_deprecate_positional_args
     def __init__(self, score_func=f_classif, *, alpha=5e-2):
@@ -744,15 +753,15 @@ class GenericUnivariateSelect(_BaseFilter):
 
     Parameters
     ----------
-    score_func : callable
+    score_func : callable, default=f_classif
         Function taking two arrays X and y, and returning a pair of arrays
         (scores, pvalues). For modes 'percentile' or 'kbest' it can return
         a single array scores.
 
-    mode : {'percentile', 'k_best', 'fpr', 'fdr', 'fwe'}
+    mode : {'percentile', 'k_best', 'fpr', 'fdr', 'fwe'}, default='percentile'
         Feature selection mode.
 
-    param : float or int depending on the feature selection mode
+    param : float or int depending on the feature selection mode, default=1e-5
         Parameter of the corresponding mode.
 
     Attributes
@@ -775,18 +784,19 @@ class GenericUnivariateSelect(_BaseFilter):
     >>> X_new.shape
     (569, 20)
 
-    See also
+    See Also
     --------
-    f_classif: ANOVA F-value between label/feature for classification tasks.
-    mutual_info_classif: Mutual information for a discrete target.
-    chi2: Chi-squared stats of non-negative features for classification tasks.
-    f_regression: F-value between label/feature for regression tasks.
-    mutual_info_regression: Mutual information for a continuous target.
-    SelectPercentile: Select features based on percentile of the highest scores.
-    SelectKBest: Select features based on the k highest scores.
-    SelectFpr: Select features based on a false positive rate test.
-    SelectFdr: Select features based on an estimated false discovery rate.
-    SelectFwe: Select features based on family-wise error rate.
+    f_classif : ANOVA F-value between label/feature for classification tasks.
+    mutual_info_classif : Mutual information for a discrete target.
+    chi2 : Chi-squared stats of non-negative features for classification tasks.
+    f_regression : F-value between label/feature for regression tasks.
+    mutual_info_regression : Mutual information for a continuous target.
+    SelectPercentile : Select features based on percentile of the highest
+        scores.
+    SelectKBest : Select features based on the k highest scores.
+    SelectFpr : Select features based on a false positive rate test.
+    SelectFdr : Select features based on an estimated false discovery rate.
+    SelectFwe : Select features based on family-wise error rate.
     """
 
     _selection_modes = {'percentile': SelectPercentile,
